@@ -7,7 +7,7 @@ extends 'Image::TextMode::Format', 'Image::TextMode::Canvas';
 has 'header' =>
     ( is => 'rw', isa => 'HashRef', default => sub { { version => 1 } } );
 
-sub extensions { return 'adf' };
+sub extensions { return 'adf' }
 
 no Moose;
 
